@@ -3,7 +3,7 @@ BEGIN {
   $Bio::GFF3::LowLevel::Parser::AUTHORITY = 'cpan:RBUELS';
 }
 {
-  $Bio::GFF3::LowLevel::Parser::VERSION = '1.6';
+  $Bio::GFF3::LowLevel::Parser::VERSION = '1.7';
 }
 # ABSTRACT: a fast, low-level gff3 parser
 
@@ -53,6 +53,12 @@ sub _open {
 }
 
 
+sub max_lookback {
+    my ( $self, $count ) = @_;
+    $self->{max_lookback} = $count
+}
+
+
 sub new {
     my $class = shift;
     require Bio::GFF3::LowLevel::Parser::1_0_backcompat;
@@ -126,6 +132,9 @@ sub _buffer_items {
             croak "$self->{filethings}[0]:$.: parse error.  Cannot parse '$line'.";
         }
 
+        # buffer old features if we are starting to approach our mem limit
+        $self->_ensure_lookback_limit;
+
         # return now if we were able to find some things to put in the
         # output buffer
         return if $self->_buffered_items_count;
@@ -161,6 +170,22 @@ EOM
     }
 }
 
+sub _ensure_lookback_limit {
+    my ( $self ) = @_;
+
+    return unless defined $self->{max_lookback};
+
+    my $toplevel = $self->{under_construction_top_level};
+    my $byid = $self->{under_construction_by_id};
+    my $out_buffer = $self->{item_buffer};
+    no warnings 'uninitialized';
+    while( @$toplevel > $self->{max_lookback} ) {
+        my $f = shift @$toplevel;
+        delete $byid->{$_} for map @{$_->{attributes}{ID}}, @$f;
+        push @$out_buffer, $f;
+    }
+}
+
 # makes a string with a tabular report of all the currently unresolved
 # references: Parent, Derives_from, etc.
 sub _unresolved_references_report {
@@ -421,6 +446,13 @@ Comments are parsed into a hashref of the form:
 Make a new parser object that will parse the GFF3 from all of the files
 or filehandles that you give it, as if they were all a single stream.
 
+=head2 max_lookback( $features )
+
+Set a maximum number of features the parser will keep buffered in case
+there are features later in the file referring to it.  By default,
+there is no limit, with the parser instead relying on the presense of
+'###' marks in the GFF3 file.
+
 =head2 new
 
 Returns a wrapped copy of this parser that returns data that is backward-compatible with what the 1.0 version of this parser returned.  Do not use in new code.
