@@ -2,10 +2,10 @@ package Bio::GFF3::Transform::SyncDirectives;
 BEGIN {
   $Bio::GFF3::Transform::SyncDirectives::AUTHORITY = 'cpan:RBUELS';
 }
-BEGIN {
-  $Bio::GFF3::Transform::SyncDirectives::VERSION = '1.0';
+{
+  $Bio::GFF3::Transform::SyncDirectives::VERSION = '1.7';
 }
-# ABSTRACT: insert sync (###) directives into an existing GFF3 file.
+# ABSTRACT: insert sync (###) directives into an existing GFF3 file.  WARNING: this module does not really work in the general case, read the DESCRIPTION section below.
 
 use strict;
 use warnings;
@@ -63,7 +63,7 @@ sub gff3_add_sync_directives {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -71,7 +71,7 @@ sub gff3_add_sync_directives {
 
 =head1 NAME
 
-Bio::GFF3::Transform::SyncDirectives - insert sync (###) directives into an existing GFF3 file.
+Bio::GFF3::Transform::SyncDirectives - insert sync (###) directives into an existing GFF3 file.  WARNING: this module does not really work in the general case, read the DESCRIPTION section below.
 
 =head1 SYNOPSIS
 
@@ -81,6 +81,15 @@ Bio::GFF3::Transform::SyncDirectives - insert sync (###) directives into an exis
     open my $output_fh, '>', 'myoutputfile.gff3';
     gff3_add_sync_directives( $output_fh, @input_files );
 
+=head1 DESCRIPTIONS
+
+This module, and its gff3_insert_sync_directives script, have some
+important caveats: they do not support C<Derives_from>, they will not
+work if any child features come in the file B<before> their parent
+(which in practice is unusual), and they do not work when more than
+one feature line has the same ID.  Perhaps in the future I may get
+around to writing a more capable version of this.
+
 =head1 FUNCTIONS
 
 All functions below are EXPORT_OK.
@@ -103,8 +112,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
